==> fwdi-0.0.41-py3-none-any.whl: fwdi/Utilites/system_logging.py <==
import logging.handlers
import os
from threading import get_ident, current_thread, get_native_id
from enum import Enum
import logging
from logging.handlers import RotatingFileHandler

MEGA_BYTE:int = 1 * 1024 * 1024
LOG_DIR:str = 'logs'

class TypeLogging(Enum):
    DEBUG = 0
    INFO = 1
    WARNING = 2
    ERROR = 3
    CRITICAL = 4
    NOTSET = 5

if not os.path.exists(LOG_DIR):
    os.mkdir(LOG_DIR)

handler = RotatingFileHandler(f"{LOG_DIR}/__system__.log", maxBytes=10*MEGA_BYTE, backupCount=50)
logging.basicConfig(encoding='utf-8', 
                    level=logging.DEBUG, 
                    format='%(asctime)s | %(name)s | %(levelname)s | %(thread)d | %(message)s', 
                    handlers=[handler])



class SysLogging():
    def __init__(self, filename:str, logging_level=TypeLogging.DEBUG, size_log:int=10, count_logs:int=50):
        
        self.__filename = f'{LOG_DIR}/ITSHelper_{filename}.log'

        match(logging_level):
            case TypeLogging.INFO:
                level_log = logging.INFO
            case TypeLogging.DEBUG:
                level_log = logging.DEBUG
            case TypeLogging.WARNING:
                level_log = logging.WARNING
            case TypeLogging.ERROR:
                level_log = logging.ERROR
            case TypeLogging.CRITICAL:
                level_log = logging.CRITICAL
            case TypeLogging.NOTSET:
                level_log = logging.NOTSET
        
        self.__logger = logging.getLogger(self.__filename)
        self.__logger.setLevel(level_log)
        
        formatter = logging.Formatter('%(name)s | %(asctime)s | %(levelname)s | %(thread)d | %(message)s')
        handler = RotatingFileHandler(self.__filename, maxBytes=size_log*MEGA_BYTE, backupCount=count_logs)
        self.__logger.addHandler(handler)

        file_handler = logging.FileHandler(self.__filename)
        file_handler.setLevel(level_log)
        file_handler.setFormatter(formatter)
        self.__logger.addHandler(file_handler)

    def __call__(self, message:str, type_log:str='INFO', args:any=None):
        message = f"ident={get_ident()}, id={get_native_id()}::{message}"
        match(type_log.upper()):
            case 'INFO':
                self.__logger.info(message)
            case 'DEBUG':
                self.__logger.debug(message)
            case 'WARNING':
                self.__logger.warning(message)
            case 'ERROR':
                self.__logger.error(message)
            case _:
                self.__logger.info(message)

==> fwdi-0.0.42-py3-none-any.whl: fwdi/Utilites/system_logging.py <==
import logging.handlers
import os
from threading import get_ident, current_thread, get_native_id
from enum import Enum
import logging
from logging.handlers import RotatingFileHandler

MEGA_BYTE:int = 1 * 1024 * 1024
LOG_DIR:str = 'logs'

class TypeLogging(Enum):
    DEBUG = 0
    INFO = 1
    WARNING = 2
    ERROR = 3
    CRITICAL = 4
    NOTSET = 5

if not os.path.exists(LOG_DIR):
    os.mkdir(LOG_DIR)

size_main_log_file = 10 * 1024 * 1024
handler = RotatingFileHandler(f"{LOG_DIR}/__system__.log", maxBytes=size_main_log_file, backupCount=50)
logging.basicConfig(encoding='utf-8', 
                    level=logging.DEBUG, 
                    format='%(asctime)s | %(name)s | %(levelname)s | %(thread)d | %(message)s', 
                    handlers=[handler])



class SysLogging():
    def __init__(self, filename:str, logging_level=TypeLogging.DEBUG, size_log:int=10, count_logs:int=50):
        
        self.__filename = f'{LOG_DIR}/ITSHelper_{filename}.log'

        match(logging_level):
            case TypeLogging.INFO:
                level_log = logging.INFO
            case TypeLogging.DEBUG:
                level_log = logging.DEBUG
            case TypeLogging.WARNING:
                level_log = logging.WARNING
            case TypeLogging.ERROR:
                level_log = logging.ERROR
            case TypeLogging.CRITICAL:
                level_log = logging.CRITICAL
            case TypeLogging.NOTSET:
                level_log = logging.NOTSET
        
        self.__logger = logging.getLogger(self.__filename)
        self.__logger.setLevel(level_log)
        
        formatter = logging.Formatter('%(name)s | %(asctime)s | %(levelname)s | %(thread)d | %(message)s')
        handler = RotatingFileHandler(self.__filename, maxBytes=size_log*MEGA_BYTE, backupCount=count_logs)
        self.__logger.addHandler(handler)

        file_handler = logging.FileHandler(self.__filename)
        file_handler.setLevel(level_log)
        file_handler.setFormatter(formatter)
        self.__logger.addHandler(file_handler)

    def __call__(self, message:str, type_log:str='INFO', args:any=None):
        message = f"ident={get_ident()}, id={get_native_id()}::{message}"
        match(type_log.upper()):
            case 'INFO':
                self.__logger.info(message)
            case 'DEBUG':
                self.__logger.debug(message)
            case 'WARNING':
                self.__logger.warning(message)
            case 'ERROR':
                self.__logger.error(message)
            case _:
                self.__logger.info(message)
